#!/bin/sh
# test we are root
if [ "$(id -u)" != "0" ]; then
   echo "run as root now exitting"
   exit 1
fi

export CFLAGS="-march=armv8-a+crc -mtune=cortex-a72 -Os -pipe"
export CXXFLAGS="-march=armv8-a+crc -mtune=cortex-a72 -Os -pipe -fno-exceptions -fno-rtti"

P=feh
V=3.10
SRC=$P-$V
USER=`cat /etc/sysconfig/tcuser`

LIST="compiletc submitqc libX11-dev imlib2-dev curl-dev libexif-dev libXinerama-dev libXt-dev file-dev"
for Z in $LIST
    do 
    su -c "tce-load -i $Z" $USER
done

# list may have more than loaded
cd /usr/local/lib
rm -rf *.la
rm -rf gcc/aarch64-unknown-linux-gnu/12.2.0/plugin/*.la
rm -rf gcc/aarch64-unknown-linux-gnu/12.2.0/*.la
rm -rf gprofng/*.la 
rm -rf python3.8/site-packages/*.la
rm -rf pkcs11/*.la
rm -rf cairo/*.la
rm -rf gtk-2.0/modules/*.la
rm -rf gtk-2.0/2.10.0/printbackends/*.la
rm -rf gtk-2.0/2.10.0/immodules/*.la
rm -rf gtk-2.0/2.10.0/engines/*.la
rm -rf imlib2/loaders/*.la
rm -rf imlib2/filters/*.la
rm -rf gdk-pixbuf-2.0/2.10.0/loaders/*.la
rm -rf libnl/cli
cd /tmp
rm -rf /usr/lib/*.la


su -c "/usr/local/bin/wget -nc --no-check-certificate \
https://$P.finalrewind.org/$SRC.tar.bz2 "  $USER

tar jxvf $SRC*bz2
cd $SRC
make prefix=/usr/local magic=1 exif=1 # 25 seconds
make install DESTDIR=/tmp/$P # -strip fails
cd /tmp

# feh -v gives compile switches info

# no doc
##########
rm -rf $P/usr/local/share/doc 
rm -rf $P/usr/local/share/man 

# main + remove svg files
######
strip --strip-unneeded $P/usr/local/bin/$P
mkdir -p $P/usr/local/share/pixmaps
cp $P/usr/local/share/icons/hicolor/48x48/apps/$P.png $P/usr/local/share/pixmaps
echo 'X-FullPathIcon=/usr/local/share/pixmaps/feh.png' >> $P/usr/local/share/applications/$P.desktop
rm -rf $P/usr/local/share/feh/images/feh.svg
rm -rf $P/usr/local/share/icons/hicolor/scalable

mkdir -p $P/usr/local/share/doc/$P
cp $SRC/COPYING $P/usr/local/share/doc/$P/

# tce.install
#############
mkdir -p $P/usr/local/tce.installed
cat << EOF >> $P/usr/local/tce.installed/$P 
#!/bin/sh
gtk-update-icon-cache -q -f -t /usr/local/share/icons/hicolor
EOF
chown -R root:staff $P/usr/local/tce.installed
chmod -R 775 $P/usr/local/tce.installed

# feh appears in hackedbox but not in menu for icewm
APP=$P/usr/local/share/applications/$P.desktop
sed 's|Graphics;2DGraphics;Viewer;|System;Utilities;Applications;System Tools|' -i $APP  
sed 's|true|false|' -i $APP	

# TCZ them
###########
LIST2="$P "
for Z in $LIST2
do
	mksquashfs $Z $Z.tcz
	md5sum $Z.tcz > $Z.tcz.md5.txt
	cd $Z
	find usr -not -type d > /tmp/$Z.tcz.list
        sed 's|usr|/usr|g' -i /tmp/$Z.tcz.list
	cd /tmp
done

ls -hal

echo 'Title:          feh.tcz
Description:    Xorg image viewer 
Version:        3.10
Author:         feh team 
Original-site:  http://feh.finalrewind.org/
Copying-policy: accompanied
Size:           132K          		
Extension_by:   aus9
Tags:           image viewer gif png jpeg tiff webp
Comments:       image viewer aimed mostly at terminal users
                online help 
                https://man.finalrewind.org/1/feh/

                feh can view online images,  example
                $  feh https://i.imgur.com/w5a44h6.jpeg

                slideshow is the default mode so run feh in your
                photo/pictures dir without any switch. $ feh

                wbar feh icon will bork unless you have an image
                in your home dir
            
Change-log:     2020/09/27 v 3.5 on 12.x
Current:        2023/06/22 v 3.10 on 14.x  ' > $P.tcz.info

readelf -d $P/usr/local/bin/$P | grep 'NEEDED'
################################
#[libcurl.so.4]curl
#[libmagic.so.1]file
#[libXinerama.so.1]libXinerama
#[libexif.so.12]  libexif
#[libpng16.so.16]libpng -> imlib2
#[libX11.so.6]libX11  libXext -> imlib2      
#[libImlib2.so.1]imlib2

# feh needs more TCEs thanks to GNUser forum post in TCE bugs
# gtk2 has the tce.install command
echo 'curl.tcz
file.tcz
libXinerama.tcz
libexif.tcz
imlib2.tcz
gtk2.tcz
libjpeg-turbo-bin.tcz
jpegexiforient.tcz' > $P.tcz.dep

submitqc --libs
rm -rf *.zsync


